==> aliyun-python-sdk-iot-8.44.0.tar.gz: aliyun-python-sdk-iot-8.44.0/aliyunsdkiot/request/v20180120/BatchCreateSoundCodeLabelWithLabelsRequest.py <==
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest
from aliyunsdkiot.endpoint import endpoint_data

class BatchCreateSoundCodeLabelWithLabelsRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'Iot', '2018-01-20', 'BatchCreateSoundCodeLabelWithLabels')
		self.set_method('POST')
		if hasattr(self, "endpoint_map"):
			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
		if hasattr(self, "endpoint_regional"):
			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())


	def get_ScheduleCode(self):
		return self.get_body_params().get('ScheduleCode')

	def set_ScheduleCode(self,ScheduleCode):
		self.add_body_params('ScheduleCode', ScheduleCode)

	def get_Description(self):
		return self.get_body_params().get('Description')

	def set_Description(self,Description):
		self.add_body_params('Description', Description)

	def get_IotInstanceId(self):
		return self.get_body_params().get('IotInstanceId')

	def set_IotInstanceId(self,IotInstanceId):
		self.add_body_params('IotInstanceId', IotInstanceId)

	def get_Labelss(self):
		return self.get_body_params().get('Labels')

	def set_Labelss(self, Labelss):
		for depth1 in range(len(Labelss)):
			if Labelss[depth1] is not None:
				self.add_body_params('Labels.' + str(depth1 + 1) , Labelss[depth1])

==> aliyun-python-sdk-iot-8.59.0.tar.gz: aliyun-python-sdk-iot-8.59.0/aliyunsdkiot/request/v20180120/BatchCreateSoundCodeLabelWithLabelsRequest.py <==
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest
from aliyunsdkiot.endpoint import endpoint_data

class BatchCreateSoundCodeLabelWithLabelsRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'Iot', '2018-01-20', 'BatchCreateSoundCodeLabelWithLabels','iot')
		self.set_method('POST')
		if hasattr(self, "endpoint_map"):
			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
		if hasattr(self, "endpoint_regional"):
			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())


	def get_ScheduleCode(self):
		return self.get_body_params().get('ScheduleCode')

	def set_ScheduleCode(self,ScheduleCode):
		self.add_body_params('ScheduleCode', ScheduleCode)

	def get_Description(self):
		return self.get_body_params().get('Description')

	def set_Description(self,Description):
		self.add_body_params('Description', Description)

	def get_IotInstanceId(self):
		return self.get_body_params().get('IotInstanceId')

	def set_IotInstanceId(self,IotInstanceId):
		self.add_body_params('IotInstanceId', IotInstanceId)

	def get_Labelss(self):
		return self.get_body_params().get('Labels')

	def set_Labelss(self, Labelss):
		for depth1 in range(len(Labelss)):
			if Labelss[depth1] is not None:
				self.add_body_params('Labels.' + str(depth1 + 1) , Labelss[depth1])
